@@ -2,7 +2,7 @@
 #
 # Exceptions - A class for XlsxWriter exceptions.
 #
-# Copyright 2013-2019, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
 #
 
 
@@ -34,10 +34,6 @@ class DuplicateWorksheetName(XlsxInputError):
     """Worksheet name already exists."""
 
 
-class ReservedWorksheetName(XlsxInputError):
-    """Worksheet name 'History' is reserved by Excel."""
-
-
 class UndefinedImageSize(XlsxFileError):
     """No size data found in image file."""
 
