@@ -2,7 +2,7 @@
 #
 # Styles - A class for writing the Excel XLSX Worksheet file.
 #
-# Copyright 2013-2017, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
 #
 
 # Package imports.
@@ -40,6 +40,7 @@ class Styles(xmlwriter.XMLwriter):
         self.dxf_formats = []
         self.has_hyperlink = False
         self.hyperlink_font_id = 0
+        self.has_comments = False
 
     ###########################################################################
     #
@@ -103,6 +104,7 @@ class Styles(xmlwriter.XMLwriter):
         self.fill_count = properties[5]
         self.custom_colors = properties[6]
         self.dxf_formats = properties[7]
+        self.has_comments = properties[8]
 
     def _get_palette_color(self, color):
         # Convert the RGB color.
@@ -197,7 +199,12 @@ class Styles(xmlwriter.XMLwriter):
 
     def _write_fonts(self):
         # Write the <fonts> element.
-        attributes = [('count', self.font_count)]
+        if self.has_comments:
+            # Add extra font for comments.
+            attributes = [('count', self.font_count + 1)]
+        else:
+            attributes = [('count', self.font_count)]
+
         self._xml_start_tag('fonts', attributes)
 
         # Write the font elements for xf_format objects that have them.
@@ -205,6 +212,9 @@ class Styles(xmlwriter.XMLwriter):
             if xf_format.has_font:
                 self._write_font(xf_format)
 
+        if self.has_comments:
+            self._write_comment_font()
+
         self._xml_end_tag('fonts')
 
     def _write_font(self, xf_format, is_dxf_format=False):
@@ -281,6 +291,17 @@ class Styles(xmlwriter.XMLwriter):
 
         self._xml_end_tag('font')
 
+    def _write_comment_font(self):
+        # Write the <font> element for comments.
+        self._xml_start_tag('font')
+
+        self._xml_empty_tag('sz', [('val', 8)])
+        self._write_color('indexed', 81)
+        self._xml_empty_tag('name', [('val', 'Tahoma')])
+        self._xml_empty_tag('family', [('val', 2)])
+
+        self._xml_end_tag('font')
+
     def _write_underline(self, underline):
         # Write the underline font element.
 
@@ -366,6 +387,11 @@ class Styles(xmlwriter.XMLwriter):
             'gray0625',
         )
 
+        # Special handling for pattern only case.
+        if not fg_color and not bg_color and patterns[pattern]:
+            self._write_default_fill(patterns[pattern])
+            return
+
         self._xml_start_tag('fill')
 
         # The "none" pattern is handled differently for dxf formats.
@@ -384,7 +410,7 @@ class Styles(xmlwriter.XMLwriter):
             bg_color = self._get_palette_color(bg_color)
             self._xml_empty_tag('bgColor', [('rgb', bg_color)])
         else:
-            if not is_dxf_format:
+            if not is_dxf_format and pattern <= 1:
                 self._xml_empty_tag('bgColor', [('indexed', 64)])
 
         self._xml_end_tag('patternFill')
