@@ -9,10 +9,7 @@
 
 # Standard packages.
 import re
-import codecs
-
-# Standard packages in Python 2/3 compatibility mode.
-from .compatibility import StringIO
+from io import StringIO
 
 
 class XMLwriter(object):
@@ -38,7 +35,7 @@ class XMLwriter(object):
             self.fh = filename
         else:
             self.internal_fh = True
-            self.fh = codecs.open(filename, 'w', 'utf-8')
+            self.fh = open(filename, 'w', encoding='utf-8')
 
     def _xml_close(self):
         # Close the XML filehandle if we created it.
@@ -185,11 +182,11 @@ class XMLwriter(object):
         except TypeError:
             return attribute
 
-        attribute = re.sub('[&]', '&amp;', attribute)
-        attribute = re.sub('["]', '&quot;', attribute)
-        attribute = re.sub('[<]', '&lt;', attribute)
-        attribute = re.sub('[>]', '&gt;', attribute)
-        attribute = re.sub('[\n]', '&#xA;', attribute)
+        attribute = attribute.replace('&', '&amp;')
+        attribute = attribute.replace('"', '&quot;')
+        attribute = attribute.replace('<', '&lt;')
+        attribute = attribute.replace('>', '&gt;')
+        attribute = attribute.replace('\n', '&#xA;')
 
         return attribute
 
@@ -203,8 +200,8 @@ class XMLwriter(object):
         except TypeError:
             return data
 
-        data = re.sub('[&]', '&amp;', data)
-        data = re.sub('[<]', '&lt;', data)
-        data = re.sub('[>]', '&gt;', data)
+        data = data.replace('&', '&amp;')
+        data = data.replace('<', '&lt;')
+        data = data.replace('>', '&gt;')
 
         return data
